Automates repetitive Data Science chores like importing libraries and reading data. Just do - from istart import * . It gives you the following:
  - import pandas as pd
   - import numpy as np
   - read_data(filename)

I'm working on more! Let me know if you have suggestions.
